@@ -526,7 +526,7 @@ class SetupReproEnvPlugin(PluginInterface):
         args = parsed_args
 
         download_options = _DownloadOptions(
-            db=args.download_binaries,
+            db=(not args.skip_binaries),
             ds=args.download_symbols,
             da=args.download_artifacts,
             dv=args.download_python_venv,
@@ -557,16 +557,16 @@ class SetupReproEnvPlugin(PluginInterface):
             "-i",
             "--installDir",
             dest="install_dir",
-            required=True,
-            help="Directory to install the download archive. [REQUIRED]",
+            default="build/repro_envs",
+            help="Directory to install the download archive, [default: %(default)s]",
         )
         parser.add_argument(
             "-l",
             "--linkDir",
             dest="link_dir",
-            required=True,
+            default="repro_env",
             help="Directory to contain links to all binaries for each version "
-            "in the install directory. [REQUIRED]",
+            "in the install directory, [default: %(default)s]",
         )
         editions = ("base", "enterprise", "targeted")
         parser.add_argument(
@@ -630,38 +630,33 @@ class SetupReproEnvPlugin(PluginInterface):
             action="store_true",
             help="If specified, the last continuous version will be installed",
         )
-
         parser.add_argument(
-            "-db",
-            "--downloadBinaries",
-            dest="download_binaries",
+            "-sb",
+            "--skipBinaries",
+            dest="skip_binaries",
             action="store_true",
-            default=True,
-            help="whether to download binaries, [default: %(default)s].",
+            help="whether to skip downloading binaries.",
         )
         parser.add_argument(
             "-ds",
             "--downloadSymbols",
             dest="download_symbols",
             action="store_true",
-            default=False,
-            help="whether to download debug symbols, [default: %(default)s].",
+            help="whether to download debug symbols.",
         )
         parser.add_argument(
             "-da",
             "--downloadArtifacts",
             dest="download_artifacts",
             action="store_true",
-            default=False,
-            help="whether to download artifacts, [default: %(default)s].",
+            help="whether to download artifacts.",
         )
         parser.add_argument(
             "-dv",
             "--downloadPythonVenv",
             dest="download_python_venv",
             action="store_true",
-            default=False,
-            help="whether to download python venv, [default: %(default)s].",
+            help="whether to download python venv.",
         )
         parser.add_argument(
             "-ec",
@@ -683,7 +678,6 @@ class SetupReproEnvPlugin(PluginInterface):
             "--debug",
             dest="debug",
             action="store_true",
-            default=False,
             help="Set DEBUG logging level.",
         )
         parser.add_argument(
@@ -691,7 +685,6 @@ class SetupReproEnvPlugin(PluginInterface):
             "--require-push",
             dest="require_push",
             action="store_true",
-            default=False,
             help="Require the push task to be successful for assets to be downloaded",
         )
         # Hidden flag to write out the Evergreen versions of the downloaded binaries.
